# Steam Pipe Dreams
# Copyright (C) 2006 Andrew Wilkinson <ajw140@york.ac.uk>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

import pygame

from gfx import loadImage

class Cursor:
    NONE = 1
    SPANNER = 2
    BOMB = 3

    def __init__(self):
        self.object = None
        self.type = Cursor.NONE
        self.spanner = loadImage("spanner.png")
        self.spannerrect = self.spanner.get_rect()
        self.bomb = loadImage("bomb.png")
        self.bombrect = self.bomb.get_rect()

    def pickUp(self, obj):
        self.object = obj
        self.type = Cursor.NONE
        pygame.mouse.set_visible(False)

    def setType(self, type):
        self.type = type
        self.object = None
        pygame.mouse.set_visible(False)

    def drop(self):
        obj = self.object
        self.object = None
        self.type = Cursor.NONE
        pygame.mouse.set_visible(True)
        return obj

    def update(self, time):
        if self.object:
            x, y = pygame.mouse.get_pos()
            #TODO: Make this actually move the point to the centre of the object
            x -= 16
            y -= 16
            self.object.rect.topleft = (x, y)
        if self.type == Cursor.SPANNER:
            x, y = pygame.mouse.get_pos()
            x -= 16
            y -= 16
            self.spannerrect.topleft = (x, y)
        if self.type == Cursor.BOMB:
            x, y = pygame.mouse.get_pos()
            x -= 16
            y -= 16
            self.bombrect.topleft = (x, y)

    def render(self, screen):
        if self.object:
            self.object.render(screen)
        if self.type == Cursor.SPANNER:
            screen.blit(self.spanner, self.spannerrect)
        if self.type == Cursor.BOMB:
            screen.blit(self.bomb, self.bombrect)
