# Steam Pipe Dreams
# Copyright (C) 2006 Andrew Wilkinson <ajw140@york.ac.uk>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

import pygame
import random

from infobox import InfoBox
from cursor import Cursor
from level import LevelSet

class Game:
    def __init__(self):
        self.board = None
        self.infobox = InfoBox(self)

        self.levels = LevelSet("data/default.xml")
        self.levels.setupGame(self)

        self.cursor = Cursor()
        self.score = 0
        self.total_score = 0
        self.lives = 5

    def update(self, time):
        self.board.update(time)
        self.infobox.update(time)
        self.cursor.update(time)

    def render(self, screen):
        self.infobox.render(screen)
        self.board.render(screen)
        self.cursor.render(screen)

    def click(self, pos, button):
        return self.board.click(pos, button) or self.infobox.click(pos, button)
