# Steam Pipe Dreams
# Copyright (C) 2006 Andrew Wilkinson <ajw140@york.ac.uk>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

import pygame

import gfx
import game
import menu
import intro
import instructions
from tooltip import ToolTip

MENU = 1
PLAY = 2
BEGIN_GAME = 3
LEVEL_INTRO = 4
LEVEL_OUTRO = 5
GAME_WIN = 6
GAME_LOSE = 7
VIEW_HIGH_SCORES = 8
ENTER_HIGH_SCORE = 9
PAUSE = 10
INSTRUCTIONS = 11
ASK_QUIT = 12

gm = None
mu = None
state = MENU
outro = None
endscreen = None
tooltip = None
askquit = None

def main():
    global gm, mu, state, tooltip

    try:
        import psyco
        psyco.profile()
    except Exception, r:
        print 'Psyco not found. If the game runs too slowly, '
        print 'install Psyco from http://psyco.sf.net/'

    pygame.init()

    screen = pygame.display.set_mode((800, 600), pygame.DOUBLEBUF | pygame.HWSURFACE)
    pygame.display.set_caption("Steam Pipe Dreams")

    bg = gfx.Background()
    gm = game.Game()
    mu = menu.Menu()
    instruct = instructions.Instructions()

    mouse_pos = (0, 0)
    mouse_time = 0

    quit = False
    clk, frames = pygame.time.Clock(), 0
    while not quit:
        clk.tick()
        frames += 1
        if frames == 1000:
            print "%.3f fps" % (clk.get_fps(), )
            frames = 0

        if state == BEGIN_GAME:
            gm.levels.setupGame(gm)
            inro = intro.Intro()
            state = LEVEL_INTRO

        # do event handling
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                quit = True
            elif event.type == pygame.MOUSEBUTTONUP:
                if state == MENU:
                    mu.click(event.pos, event.button)
                elif state == PLAY:
                    gm.click(event.pos, event.button)
                elif state == PAUSE:
                    gm.infobox.click(event.pos, event.button)
                elif state == LEVEL_INTRO:
                    inro.click(event.pos, event.button)
                elif state == LEVEL_OUTRO:
                    outro.click(event.pos, event.button)
                elif state in [GAME_WIN, GAME_LOSE]:
                    endscreen.click(event.pos, event.button)
                elif state == INSTRUCTIONS:
                    instruct.click(event.pos, event.button)
                elif state == ASK_QUIT:
                    askquit.click(event.pos, event.button)
            elif event.type == pygame.MOUSEMOTION:
               mouse_pos = event.pos
               mouse_time = pygame.time.get_ticks()
               tooltip = None
        # done event handling

        if pygame.time.get_ticks() - mouse_time > 2000 and state == PLAY and tooltip is None:
            s = gm.infobox.tooltip(mouse_pos)
            if not s:
                s = gm.board.tooltip(mouse_pos)
            if s:
                tooltip = ToolTip(s, mouse_pos[0], mouse_pos[1]+15)

        t = clk.get_time()/1000.0
        if state == MENU:
            mu.update(t)
        elif state == PLAY:
            gm.update(t)
            if tooltip:
                tooltip.update(t)
        elif state == LEVEL_INTRO:
            inro.update(t)
        elif state == LEVEL_OUTRO:
            outro.update(t)
        elif state in [GAME_WIN, GAME_LOSE]:
            endscreen.update(t)

        screen.blit(bg.image, bg.rect)
        if state == MENU:
            gm.cursor.drop()
            mu.render(screen)
        elif state == PLAY:
            gm.render(screen)
            if tooltip:
                tooltip.render(screen)
        elif state == PAUSE:
            gm.infobox.render(screen)
            gm.cursor.render(screen)
            paused = gfx.loadImage("paused.png")
            pausedrect = paused.get_rect()
            pausedrect.topleft = (400, 280)
            screen.blit(paused, pausedrect)
        elif state == LEVEL_INTRO:
            inro.render(screen)
        elif state == LEVEL_OUTRO:
            outro.render(screen)
        elif state in [GAME_WIN, GAME_LOSE]:
            endscreen.render(screen)
        elif state == INSTRUCTIONS:
            instruct.render(screen)
        elif state == ASK_QUIT:
            askquit.render(screen)

        pygame.display.flip()
