# Steam Pipe Dreams
# Copyright (C) 2006 Andrew Wilkinson <ajw140@york.ac.uk>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

import pygame

import main
import gamewin
import gamelose

class Outro:
    def __init__(self, win):
        self.win = win

        self.bigfont = pygame.font.Font(pygame.font.match_font("Arial"), 80)
        self.smallfont = pygame.font.Font(pygame.font.match_font("Arial"), 40)

        if win:
            self.bigmsg = self.bigfont.render("Congratulations!", True, (0, 0, 0))
            self.bigmsgrect = self.bigmsg.get_rect()
            self.bigmsgrect.topleft = (400 - self.bigmsgrect.width/2, 75)

            self.msg1 = self.smallfont.render("You scored %i points" % (main.gm.score, ), True, (0, 0, 0))
            self.msg1rect = self.msg1.get_rect()
            self.msg1rect.topleft = (400 - self.msg1rect.width/2, 200)

            self.msg2 = self.smallfont.render("giving you a total of %i points." % (main.gm.total_score, ), True, (0, 0, 0))
            self.msg2rect = self.msg2.get_rect()
            self.msg2rect.topleft = (400 - self.msg2rect.width/2, 250)
        else:
            self.bigmsg = self.bigfont.render("Oh dear!", True, (0, 0, 0))
            self.bigmsgrect = self.bigmsg.get_rect()
            self.bigmsgrect.topleft = (400 - self.bigmsgrect.width/2, 75)

            self.msg1 = self.smallfont.render("You failed to complete the level in time.", True, (0, 0, 0))
            self.msg1rect = self.msg1.get_rect()
            self.msg1rect.topleft = (400 - self.msg1rect.width/2, 200)

            self.msg2 = self.smallfont.render("You have %i lives left." % (main.gm.lives, ), True, (0, 0, 0))
            self.msg2rect = self.msg2.get_rect()
            self.msg2rect.topleft = (400 - self.msg2rect.width/2, 250)

        self.clickmsg = self.smallfont.render("Click To Continue", True, (255, 255, 255))
        self.clickmsgrect = self.clickmsg.get_rect()
        self.clickmsgrect.topleft = (400 - self.clickmsgrect.width/2, 500)

    def update(self, time):
        pass

    def render(self, screen):
        screen.blit(self.bigmsg, self.bigmsgrect)
        screen.blit(self.msg1, self.msg1rect)
        screen.blit(self.msg2, self.msg2rect)
        screen.blit(self.clickmsg, self.clickmsgrect)

    def click(self, pos, button):
        if button == 1:
            if self.win:
                if main.gm.levels.currentlevel + 1 < len(main.gm.levels.levels):
                    main.gm.levels.currentlevel = main.gm.levels.currentlevel + 1
                    main.state = main.BEGIN_GAME
                else:
                    main.endscreen = gamewin.GameWin()
                    main.state = main.GAME_WIN
            else:
                if main.gm.lives == 0:
                    main.endscreen = gamelose.GameLose()
                    main.state = main.GAME_LOSE
                else:
                    main.state = main.BEGIN_GAME
