# Steam Pipe Dreams
# Copyright (C) 2006 Andrew Wilkinson <ajw140@york.ac.uk>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

from pipedreams.gfx import loadImage

from piece import Piece

limit = 30.0

class CompressorRight(Piece):
    points = 250
    def __init__(self):
        Piece.__init__(self)

        self.image = loadImage("compressor_right.png")
        self.accept = [Piece.LEFT]
        self.pipe = True
        self.no_graph = True
        self.volume = 10
        self.rotate = CompressorDown

    def update(self, time):
        Piece.update(self, time)
        if self.pressure > 1 and self.right and Piece.LEFT in self.right.accept:
            steam = float(self.steam)
            # this is the value that would be moved by the pressure gradiant
            pressuresize = min(max(1, 5*(self.pressure - self.right.pressure)), steam/2.0)
            size = max(min(limit, self.steam), pressuresize)
            self.right.acceptSteam({"O": self.O*(size/steam),
                               "R": self.R*(size/steam),
                               "G": self.G*(size/steam),
                               "B": self.B*(size/steam),
                               "Y": self.Y*(size/steam)})
            self.releaseSteam(size)

class CompressorDown(Piece):
    points = 250
    def __init__(self):
        Piece.__init__(self)

        self.image = loadImage("compressor_down.png")
        self.accept = [Piece.UP]
        self.pipe = True
        self.no_graph = True
        self.volume = 10
        self.rotate = CompressorLeft

    def update(self, time):
        Piece.update(self, time)
        if self.pressure > 1 and self.down and Piece.UP in self.down.accept:
            steam = float(self.steam)
            size = min(limit, self.steam)
            # this is the value that would be moved by the pressure gradiant
            pressuresize = min(max(1, 5*(self.pressure - self.down.pressure)), steam/2.0)
            size = max(min(limit, self.steam), pressuresize)
            self.down.acceptSteam({"O": self.O*(size/steam),
                               "R": self.R*(size/steam),
                               "G": self.G*(size/steam),
                               "B": self.B*(size/steam),
                               "Y": self.Y*(size/steam)})
            self.releaseSteam(size)

class CompressorLeft(Piece):
    points = 250
    def __init__(self):
        Piece.__init__(self)

        self.image = loadImage("compressor_left.png")
        self.accept = [Piece.RIGHT]
        self.pipe = True
        self.no_graph = True
        self.volume = 10
        self.rotate = CompressorUp

    def update(self, time):
        Piece.update(self, time)
        if self.pressure > 1 and self.left and Piece.RIGHT in self.left.accept:
            steam = float(self.steam)
            # this is the value that would be moved by the pressure gradiant
            pressuresize = min(max(1, 5*(self.pressure - self.left.pressure)), steam/2.0)
            size = max(min(limit, self.steam), pressuresize)
            self.left.acceptSteam({"O": self.O*(size/steam),
                               "R": self.R*(size/steam),
                               "G": self.G*(size/steam),
                               "B": self.B*(size/steam),
                               "Y": self.Y*(size/steam)})
            self.releaseSteam(size)

class CompressorUp(Piece):
    points = 250
    def __init__(self):
        Piece.__init__(self)

        self.image = loadImage("compressor_up.png")
        self.accept = [Piece.DOWN]
        self.pipe = True
        self.no_graph = True
        self.volume = 10
        self.rotate = CompressorRight

    def update(self, time):
        Piece.update(self, time)
        if self.pressure > 1 and self.up and Piece.DOWN in self.up.accept:
            steam = float(self.steam)
            size = min(limit, self.steam)
            # this is the value that would be moved by the pressure gradiant
            pressuresize = min(max(1, 5*(self.pressure - self.up.pressure)), steam/2.0)
            size = max(min(limit, self.steam), pressuresize)
            self.up.acceptSteam({"O": self.O*(size/steam),
                               "R": self.R*(size/steam),
                               "G": self.G*(size/steam),
                               "B": self.B*(size/steam),
                               "Y": self.Y*(size/steam)})
            self.releaseSteam(size)
