# Steam Pipe Dreams
# Copyright (C) 2006 Andrew Wilkinson <ajw140@york.ac.uk>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

import copy

import pipedreams
from pipedreams.gfx import loadImage

from piece import Piece

class Machine(Piece):
    tooltip = "The Machine. Direct all steam from the boiler here."

    def __init__(self):
        Piece.__init__(self)

        self.image = loadImage("machine.png")
        self.accept = [Piece.LEFT]
        self.volume = 100
        self.total = {"O":0, "R":0, "G":0, "B":0, "Y":0}
        self.target = {"O":0, "R":0, "G":0, "B":0, "Y":0}
        self.rate = 4

        self.no_graph = True

    def update(self, time):
        Piece.update(self, time)
        if self.pressure >= self.start_pressure and self.pressure <= self.end_pressure:
            from pipedreams.main import gm
            before = copy.copy(self._steam)
            self.releaseSteam(self.rate)
            after = self._steam
            done = 0
            s = 0
            for k in ["O", "R", "G", "B", "Y"]:
                if self.target[k] > 0 and self.total[k] < self.target[k]:
                    self.total[k] = min(self.target[k], self.total[k] + (before[k] - after[k]))
                    s += (before[k] - after[k])
                if self.target[k] == self.total[k]:
                    done += 1
            gm.score += s
            if done == 5:
                gm.score += gm.infobox.time_left * 5
                gm.total_score += gm.score
                gm.cursor.drop()
                pipedreams.main.outro = pipedreams.outro.Outro(True)
                pipedreams.main.state = pipedreams.main.LEVEL_OUTRO
        if self.pressure > 1 and self.left and Piece.RIGHT in self.left.accept:
            self.transferSteam(self.left)

    def setTargets(self, targets):
        self.target = {"O":0, "R":0, "G":0, "B":0, "Y":0}
        for k in ["O", "R", "G", "B", "Y"]:
            if targets[0].has_key(k):
                self.target[k] = targets[0][k]
        self.start_pressure = targets[0]["min"]
        self.end_pressure = targets[0]["max"]
        if targets[0].has_key("rate"):
            self.rate = targets[0]["rate"]
