# Steam Pipe Dreams
# Copyright (C) 2006 Andrew Wilkinson <ajw140@york.ac.uk>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

import random
import math
import pygame

from pipedreams.gfx import loadImage

class SmokeController:
    def __init__(self):
        self.graphic = {"smoke": loadImage("smoke.png"), "steam": loadImage("steam.png")}
        self.smoke = []
        self.windspeed = 0
        self.winddir = 0

    def addSmoke(self, x, y):
        self.smoke.append(("smoke", x, y, 0.0))
    def addSteam(self, x, y):
        self.smoke.append(("steam", x, y, 0.0))

    def update(self, time):
        i = random.randint(0, 20)
        if i == 0:
            self.windspeed = min(8, self.windspeed + 0.2)
        elif i == 1:
            self.windspeed = max(0, self.windspeed - 0.2)
        elif i == 2:
            self.winddir = (self.winddir + 1) % 360
        elif i == 3:
            self.winddir = (self.winddir + 1) % 360
        l = []
        s, c = self.windspeed * math.sin(math.pi*self.winddir/180.0), self.windspeed * math.cos(math.pi*self.winddir/180.0)
        for type, x, y, age in self.smoke:
            age += time
            if age > (random.random() * 5) + 2:
                continue
            x += int(s + (random.random() * 6 - 3))
            y += int(c + (random.random() * 6 - 3))
            l.append((type, x, y, age))
        self.smoke = l

    def render(self, screen):
        r = pygame.Rect(0, 0, 8, 8)
        for type, x, y, age in self.smoke:
            r.topleft = (x-4, y-4)
            screen.blit(self.graphic[type], r)
