# Steam Pipe Dreams
# Copyright (C) 2006 Andrew Wilkinson <ajw140@york.ac.uk>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

import pygame

from pipedreams.gfx import loadImage

from piece import Piece

class ValveHorizontal(Piece):
    points = 100
    def __init__(self):
        Piece.__init__(self)

        self.image = loadImage("horizontal.png")
        self.handle = loadImage("valve_handle.png")
        self.handle_img = self.handle
        self.handle_rect = self.handle_img.get_rect()
        self.accept = [Piece.LEFT, Piece.RIGHT]
        self.pipe = True
        self.no_graph = True
        self.volume = 10
        self.rotate = ValveVertical
        self.limit = 0.0

    def update(self, time):
        Piece.update(self, time)
        if self.pressure > 1 and self.left and Piece.RIGHT in self.left.accept:
            self.transferSteam(self.left)
        if self.pressure > 1 and self.right and Piece.LEFT in self.right.accept:
            self.transferSteam(self.right)

    def render(self, screen):
        Piece.render(self, screen)
        self.handle_rect.topleft = (self.rect.topleft[0] + 16 - self.handle_rect.width/2, self.rect.topleft[1] + 16 - self.handle_rect.height/2)
        screen.blit(self.handle_img, self.handle_rect)

    def adjustUp(self):
        self.limit = min(1.0, self.limit + 0.1)
        self.handle_img = pygame.transform.rotate(self.handle, -270*self.limit)
        self.handle_rect = self.handle_img.get_rect()
    def adjustDown(self):
        self.limit = max(0.0, self.limit - 0.1)
        self.handle_img = pygame.transform.rotate(self.handle, -270*self.limit)
        self.handle_rect = self.handle_img.get_rect()

    def transferSteam(self, other):
        if self.pressure > other.pressure:
            steam = float(self.steam)
            size = min(max(1, 5*(self.pressure - other.pressure)), steam/2.0) * self.limit
            other.acceptSteam({"O": self.O*(size/steam),
                               "R": self.R*(size/steam),
                               "G": self.G*(size/steam),
                               "B": self.B*(size/steam),
                               "Y": self.Y*(size/steam)})
            self.releaseSteam(size)

class ValveVertical(Piece):
    points = 100
    def __init__(self):
        Piece.__init__(self)

        self.image = loadImage("vertical.png")
        self.handle = loadImage("valve_handle.png")
        self.handle_img = self.handle
        self.handle_rect = self.handle_img.get_rect()
        self.accept = [Piece.UP, Piece.DOWN]
        self.pipe = True
        self.no_graph = True
        self.volume = 10
        self.rotate = ValveHorizontal
        self.limit = 0.0

    def update(self, time):
        Piece.update(self, time)
        if self.pressure > 1 and self.down and Piece.UP in self.down.accept:
            self.transferSteam(self.down)
        if self.pressure > 1 and self.up and Piece.DOWN in self.up.accept:
            self.transferSteam(self.up)

    def render(self, screen):
        Piece.render(self, screen)
        self.handle_rect.topleft = (self.rect.topleft[0] + 16 - self.handle_rect.width/2, self.rect.topleft[1] + 16 - self.handle_rect.height/2)
        screen.blit(self.handle_img, self.handle_rect)

    def adjustUp(self):
        self.limit = min(1.0, self.limit + 0.1)
        self.handle_img = pygame.transform.rotate(self.handle, -270*self.limit)
        self.handle_rect = self.handle_img.get_rect()
    def adjustDown(self):
        self.limit = max(0.0, self.limit - 0.1)
        self.handle_img = pygame.transform.rotate(self.handle, -270*self.limit)
        self.handle_rect = self.handle_img.get_rect()

    def transferSteam(self, other):
        if self.pressure > other.pressure:
            steam = float(self.steam)
            size = min(max(1, 5*(self.pressure - other.pressure)), steam/2.0) * self.limit
            other.acceptSteam({"O": self.O*(size/steam),
                               "R": self.R*(size/steam),
                               "G": self.G*(size/steam),
                               "B": self.B*(size/steam),
                               "Y": self.Y*(size/steam)})
            self.releaseSteam(size)
